import store from "@/store";
const { dispatch } = store;
import { columns } from "./helper.js";
import { isInteger } from "@/libs/validator.js";

export default {
  components: {  },
  data() {
    return {
      logLoading: false,
      logDatas: [],
      logColumns: [],

      contract: null,
      readonly: false,
      visible: false,
      submitLoading: false,
      mainUploadStatus: false,
      secondUploadStatus: false,
      selectTab: null,

      contractFormRule: {
        odograph: [{ required: true, message: "请输入里程数", trigger: "blur" }, { validator: isInteger, trigger: "blur" } ],
        depositAmount: [{ required: true, message: "请输入押金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
        rentAmount: [{ required: true, message: "请输入月租金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
        startDate: [{ type: "date", required: true, message: "请选择开始日期", trigger: "change" }],
        endDate: [{ type: "date", required: true, message: "请选择结束日期", trigger: "change" }],
      },
      contractForm: {
        contractId: 0,
        type: 1,
        code: null,
        vehicle: null,
        source: null,
        odograph: null,
        odographEv: null,
        startDate: null,
        endDate: null,
        depositAmount: null,
        rentAmount: null,
        leaseType: null,
        remark: null,
        files: [],
      },
      uploadList: []
    };
  },
  computed: {
  },
  watch: {
    visible(show) {
      this.submitLoading = false;
      this.contractForm.contractId = 0;
      this.contractForm.code = null;
      this.contractForm.vehicle = null;
      this.contractForm.source = null;
      this.contractForm.odograph = null;
      this.contractForm.odographEv = null;
      this.contractForm.startDate = null;
      this.contractForm.endDate = null;
      this.contractForm.depositAmount = null;
      this.contractForm.rentAmount = null;
      this.contractForm.leaseType = null;
      this.contractForm.remark = null;
      this.contractForm.files = [];
      this.uploadList = [];

      if(show) {
        this.selectTab = "contractTab";
        const vo = this.contract.vehicleVo;
        const vehicleInfo = vo.id + " / " + vo.plateNo + " / " + vo.color + " / " + vo.brandName + " / " + vo.model;
        this.contractForm.contractId = this.contract.id;
        this.contractForm.code = this.contract.code;
        this.contractForm.vehicle = vehicleInfo;
        this.contractForm.source = this.contract.sourceVo.name;
        this.contractForm.odograph = ""+this.contract.odograph;
        this.contractForm.odographEv = ""+this.contract.odographEv;
        this.contractForm.startDate = this.contract.startDate;
        this.contractForm.endDate = this.contract.endDate;
        this.contractForm.leaseType = this.contract.leaseType;
        this.contractForm.depositAmount = ""+this.contract.depositAmount;
        this.contractForm.returnDepositAmount = ""+this.contract.returnDepositAmount;
        this.contractForm.rentAmount = ""+this.contract.rentAmount;
        this.contractForm.remark = this.contract.remark;

        if(this.contract.files) {
          this.contract.files.forEach(file => {
            const item = {id: file.id, url: file.filePath, status: "finished"};
            this.uploadList.push(item);
          })
        }

        this.listLogs();
      } else {
        this.logDatas = [];
      }
      // console.log(this.uploadList);
      // console.log(this.contractForm);
    },
  },
  methods: {
    handleView(item) {
    },
    handleRemove(file) {
      // const fileList = this.$refs.upload.fileList;
      // this.$refs.upload.fileList.splice(fileList.indexOf(file), 1);

      this.uploadList.splice(this.uploadList.indexOf(file), 1);
    },
    handleFormatError (file) {
        this.$Notice.warning({
            title: 'The file format is incorrect',
            desc: 'File format of ' + file.name + ' is incorrect, please select jpg or png.'
        });
    },
    handleMaxSize (file) {
        this.$Notice.warning({
            title: 'Exceeding file size limit',
            desc: 'File  ' + file.name + ' is too large, no more than 2M.'
        });
    },
    handleBeforeUpload(file) {
      const formData = new FormData();
      formData.append("file", file);

      const item = {id: 0, url: "", status: ""};
      this.uploadList.push(item);

      dispatch("invoke/asyncUploadFile", formData).then(res => {
        const { code, data, msg } = res;
        if(code == 1) {
          this.$Message.info("上传成功");

          item.id = data.id;
          item.url = data.filePath;
          item.status = "finished";
        } else {
          this.$Message.info("上传失败");
        }
      });
      return false;
    },
    saveVehicle() {
      // console.log(this.contractForm);
      // return;
      this.$refs.contractForm.validate(valid => {
        if (valid) {
          this.uploadList.forEach(f => {
            this.contractForm.files.push(f.id);
          })
          dispatch("invoke/asyncUpdateContract", this.contractForm).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success("合同修改成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    },
    listVehicles() {
      dispatch("invoke/asyncListNoSourceContractVehicles").then(({ data }) => {
        this.vehicles = data;
      });
    },
    listSources() {
      dispatch("invoke/asyncListSource", {}).then(({ data }) => {
        this.sources = data;
      });
    },
    listLogs() {
      const contractId = this.contract.id;
      dispatch("invoke/asyncListLogs", contractId).then(({ data }) => {
        this.logDatas = data;
      });
    }
  },
  mounted() {
    this.logColumns = columns();
  }
};
