import store from "@/store";
const { dispatch } = store;
import { isInteger } from "@/libs/validator.js";

export default {
  components: {  },
  data() {
    return {
      visible: false,
      submitLoading: false,
      mainUploadStatus: false,
      secondUploadStatus: false,
      contractFormRule: {
        vehicleId: [{
            type: "number",
            required: true,
            message: "请选择车辆",
            trigger: "change"
          }
        ],
        sourceId: [{
            type: "number",
            required: true,
            message: "请选择车源",
            trigger: "change"
          }
        ],
        odograph: [{ required: true, message: "请输入里程数", trigger: "blur" }, { validator: isInteger, trigger: "blur" } ],
        depositAmount: [{ required: true, message: "请输入押金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
        rentAmount: [{ required: true, message: "请输入月租金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
        startDate: [{
            type: "date",
            required: true,
            message: "请选择开始日期",
            trigger: "change"
          }
        ],
        endDate: [{
            type: "date",
            required: true,
            message: "请选择结束日期",
            trigger: "change"
          }
        ],
      },
      contractForm: {
        type: 1,
        vehicleId: null,
        sourceId: null,
        odograph: null,
        odographEv: null,
        startDate: null,
        endDate: null,
        depositAmount: null,
        rentAmount: null,
        leaseType: null,
        remark: null,
        files: [],
      },
      vehicles: [],
      sources: [],

      uploadList: [],
      defaultList: [],
    };
  },
  computed: {
  },
  watch: {
    visible(show) {
      this.submitLoading = false;
      this.$refs.contractForm.resetFields();

      if(show) {
        this.listVehicles();
        this.listSources();
      }
    },
  },
  methods: {
    handleView(item) {
    },
    handleRemove(file) {
      // const fileList = this.$refs.upload.fileList;
      // this.$refs.upload.fileList.splice(fileList.indexOf(file), 1);

      this.uploadList.splice(this.uploadList.indexOf(file), 1);
    },
    handleFormatError (file) {
        this.$Notice.warning({
            title: 'The file format is incorrect',
            desc: 'File format of ' + file.name + ' is incorrect, please select jpg or png.'
        });
    },
    handleMaxSize (file) {
        this.$Notice.warning({
            title: 'Exceeding file size limit',
            desc: 'File  ' + file.name + ' is too large, no more than 2M.'
        });
    },
    handleBeforeUpload(file) {
      const formData = new FormData();
      formData.append("file", file);

      const item = {id:0, url:"", status:""};
      this.uploadList.push(item);

      dispatch("invoke/asyncUploadFile", formData).then(res => {
        const { code, data, msg } = res;
        if(code == 1) {
          this.$Message.info("上传成功");

          item.id = data.id;
          item.url = data.filePath;
          item.status = "finished";
        } else {
          this.$Message.info("上传失败");
        }
      });
      return false;
    },
    saveVehicle() {
      this.$refs.contractForm.validate(valid => {
        if (valid) {
          this.uploadList.forEach(f => {
            this.contractForm.files.push(f.id);
          })
          dispatch("invoke/asyncSignContract", this.contractForm).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success("合同签订成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    },
    listVehicles() {
      dispatch("invoke/asyncListNoSourceContractVehicles").then(({ data }) => {
        this.vehicles = data;
      });
    },
    listSources() {
      dispatch("invoke/asyncListSource", {}).then(({ data }) => {
        this.sources = data;
      });
    }
  },
  mounted() {
  }
};
